pub enum Error {
DataTooLarge(u32),
ContextCreationFailed,
DecryptionFailed(i32),
InvalidHex {
input: String,
message: String,
},
InvalidKeySpec {
input: String,
message: String,
},
InvalidPath(NulError),
NoKeys,
HexDecode(FromHexError),
}Expand description
Errors returned by the public Rust API and CLI.
Variants
DataTooLarge(u32)
Input or output buffers cannot be represented with Bento4’s 32-bit size limits.
ContextCreationFailed
Bento4 did not create a decryptor context.
DecryptionFailed(i32)
Bento4 returned an error while parsing or decrypting a file or fragment.
InvalidHex
A hexadecimal KID or key had the wrong size.
InvalidKeySpec
A --key value did not follow the expected <id>:<key> format.
InvalidPath(NulError)
A path could not be passed through the C interface because it contains a NUL byte.
NoKeys
The builder was finalized without any decryption keys.
HexDecode(FromHexError)
A hexadecimal KID or key could not be decoded.